# Changelog

## [0.0.1] - 2024-10-25

Initial commit with changes

## [0.0.2] - 2024-10-26

styling updates

## [0.0.3] - 2024-12-24

Docker and api support

## [0.0.4] - 2024-12-26

Support for github actions

## [0.0.6] - 2024-12-26

Support for summary report

## [0.0.7] - 2024-12-28

Support for html reports using github actions

## [0.0.8] - 2024-12-29

Version 0.0.8: Fixed OpenAI rate-limit handling
